%% D = gendata(N, f, runs)
% generates regression data
%
% Input:
% N: the sample size
% f: the underlying regression function
% runs: the number of samples
%
% Output:
% D: a structure with the following fields:
% D.X: N by runs matrix of the X-values of the data, uniform on [-1,1]
% D.n: N by runs matrix of normally distributed noise
% D.Y: N by runs matrix of the Y-values of the data, equal to f(D.X)+D.n
% D.T: log of true cumulative density (for visualisation purposes)
%   we have D.T(n) -> -0.5(log(2\pi\sigma^2)+1)*n, the differential entropy
%
function D = gendata(N, f, runs)
  RandStream.setDefaultStream(RandStream('mt19937ar', 'Seed', 0));
  D = struct('N',N, 'f', f);
  D.X = rand(N,runs)*2-1;
  noise = randn(N,runs);
  D.Y = f(D.X) + noise;
  D.n = noise;
  D.T = cumsum(lgauss(noise,zeros(N,runs),1))';
end
