%% BMA
% Implementation of Bayesian Model Averaging
%
classdef BMA < PFS_mixture
        
    methods
        %% BMA(PFSs)
        % Constructs a BMA PFS over the given set of PFSs.
        function this = BMA(PFSs)
            Kst = length(PFSs);
            prior = arrayfun(@(l)lambda(l, Kst, 0), 1:Kst);
            this = this@PFS_mixture(PFSs, core(prior), Kst);
        end
        
        %% model_weights(x) [required by PFS_mixture]
        % Returns posterior weights of the original PFSs.
        function w = model_weights(this); w = this.core.weights; end
        
    end
end

%% specification of the prior

% lambda(l, lmax, n) returns the probability lambda_n(L=l), domain 1,...,lmax
function p = lambda(l, lmax, n); p = 1/lmax; end
