%% demo
% Script to test switch distributions and show their usage
%

% read some data
X = fileread('./overview.txt');
N = length(X);
Nslow = min([N, 6*sqrt(N)]);

% construct the two basic PFSs
e1 = Markov(0);
e2 = Markov(1);

% construct combinations
c1 = switch_fast({e1 e2}, sqrt(2));
c2 = switch_default({e1 e2});
c3 = BMA({e1 e2});
c4 = switch_slow({e1 e2});

PFSs = {e1,e2,c1,c2,c3};

% cs = {c1 c2 c3 c4};

% process data and accumulate log probabilities for all PFSs
LP = zeros(N, length(PFSs)+1);
lp = zeros(1, length(PFSs)+1);
n = 1;
tic();
do_slow = 1;
for x=X
    if do_slow
        if n>Nslow
            fprintf('Interrupting slow switch at n=%d\n', n);
            do_slow = 0;
            pslow  = NaN;
        else
            pslow = c4.predict_and_process(x);
        end
    end
    probs = [cellfun(@(e)e.predict_and_process(x), PFSs), pslow];
    lp = lp+log(probs);
    LP(n,:) = lp;
    n = n+1;
    if mod(n,100)==0, fprintf('Processed %d/%d symbols...\n', n, N); end
end
time = toc();
fprintf('Time taken: %f seconds\n', time);

% visualise results
plot(1:N, -LP + repmat(LP(:,1),1,size(LP,2)));
ylabel('Log probability difference with Markov order 0');
legend('Markov order 0', 'Markov order 1', 'Fast switch', 'Default switch', 'BMA', 'Slow switch');

            