%% switch_slow
% Implementation of the slow switch distribution
%
classdef switch_slow < PFS_mixture
   
    methods

        %% switch_slow(PFSs)
        % Constructs a switch_slow over the given set of PFSs.
        % The switching set grows linearly in the sample size.
        function this = switch_slow(PFSs)
            Kst = length(PFSs);
            this = this@PFS_mixture([PFSs PFSs], switch_core(Kst, Kst), 2*Kst);
        end
        
        %% process(x)
        % Adds frozen clones of the current unfrozen PFSs to the set of
        % switching experts.
        function process(this, x)
            Kst = this.core.Kst;
            this.PFSs(end+1:end+Kst) = PFS_mixture.clones(this.PFSs(1:Kst));
            this.process@PFS_mixture(x);
        end

        %% model_weights(x) [required by PFS_mixture]
        % Conditions the weights on only the set of stable PFSs. This
        % is the model selection criterion defined in the paper.
        function w = model_weights(this)
            w = this.core.weights(1:this.core.Kst);
            w = w/sum(w);
        end
  
        
    end

end